Pod

Trait Pod 

pub unsafe trait Pod:
    Zeroable
    + Copy
    + 'static { }
Available on crate features io and ancillary and bytemuck only.
Marker trait for “plain old data”.

The point of this trait is that once something is marked “plain old data” you can really go to town with the bit fiddling and bit casting. Therefore, it’s a relatively strong claim to make about a type. Do not add this to your type casually.

Reminder: The results of casting around bytes between data types are endian dependant. Little-endian machines are the most common, but big-endian machines do exist (and big-endian is also used for “network order” bytes).

Safety

  • The type must be inhabited (eg: no Infallible).
  • The type must allow any bit pattern (eg: no bool or char, which have illegal bit patterns).
  • The type must not contain any uninit (or padding) bytes, either in the middle or on the end (eg: no #[repr(C)] struct Foo(u8, u16), which has padding in the middle, and also no #[repr(C)] struct Foo(u16, u8), which has padding on the end).
  • The type needs to have all fields also be Pod.
  • The type needs to be repr(C) or repr(transparent). In the case of repr(C), the packed and align repr modifiers can be used as long as all other rules end up being followed.
  • It is disallowed for types to contain pointer types, Cell, UnsafeCell, atomics, and any other forms of interior mutability.
  • More precisely: A shared reference to the type must allow reads, and only reads. RustBelt’s separation logic is based on the notion that a type is allowed to define a sharing predicate, its own invariant that must hold for shared references, and this predicate is the reasoning that allow it to deal with atomic and cells etc. We require the sharing predicate to be trivial and permit only read-only access.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl Pod for f32



impl Pod for f64



impl Pod for i8



impl Pod for i16



impl Pod for i32



impl Pod for i64



impl Pod for i128



impl Pod for isize



impl Pod for u8



impl Pod for u16



impl Pod for u32



impl Pod for u64



impl Pod for u128



impl Pod for ()



impl Pod for usize



impl Pod for __m128

Available on x86-64 only.


impl Pod for __m128d

Available on x86-64 only.


impl Pod for __m128i

Available on x86-64 only.


impl Pod for __m256

Available on x86-64 only.


impl Pod for __m256d

Available on x86-64 only.


impl Pod for __m256i

Available on x86-64 only.


impl Pod for PhantomPinned



impl<T> Pod for Option<T>
where T: PodInOption,



impl<T> Pod for PhantomData<T>
where T: 'static + ?Sized,



impl<T> Pod for ManuallyDrop<T>
where T: Pod,



impl<T> Pod for Wrapping<T>
where T: Pod,



impl<T, const N: usize> Pod for [T; N]
where T: Pod,

Available on crate feature min_const_generics only.

Implementors